==> haskell-roman-numerals-0.5.1.5-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: roman-numerals
version: 0.5.1.5
id: roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
key: roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
license: BSD3
copyright: 2009–2014 Roel van Dijk
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: stable
homepage: https://github.com/roelvandijk/roman-numerals
synopsis: Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.
category: Numerical, Parsing
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Text.Numeral.Roman
abi: d3cd8fca4c1f593c09fa17141572321d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/roman-numerals-0.5.1.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/roman-numerals-0.5.1.5
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/roman-numerals-0.5.1.5
hs-libraries: HSroman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
depends:
    base-4.9.0.0 base-unicode-symbols-0.2.2.4-L8AjmazQitAEQ7hSQq5LiD
    bytestring-0.10.8.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock
haddock-html: /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-roman-numerals-0.5.1.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: roman-numerals
version: 0.5.1.5
id: roman-numerals-0.5.1.5-CRymvVwv5tbH73xozocxyM
key: roman-numerals-0.5.1.5-CRymvVwv5tbH73xozocxyM
license: BSD3
copyright: 2009–2014 Roel van Dijk
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: stable
homepage: https://github.com/roelvandijk/roman-numerals
synopsis: Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.
category: Numerical, Parsing
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Text.Numeral.Roman
abi: a84ad86d222775191a1cc333f64108a3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/roman-numerals-0.5.1.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/roman-numerals-0.5.1.5
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/roman-numerals-0.5.1.5
hs-libraries: HSroman-numerals-0.5.1.5-CRymvVwv5tbH73xozocxyM
depends:
    base-4.9.0.0 base-unicode-symbols-0.2.2.4-L8AjmazQitAEQ7hSQq5LiD
    bytestring-0.10.8.1 text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock
haddock-html: /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
